@@ -435,4 +435,27 @@ def curve_with_spread(value_date: str):
                             spread_handles,
                             spread_dates)
     spread_curve_handle = ql.YieldTermStructureHandle(spread_curve)
-    return spread_curve_handle
\ No newline at end of file
+    return spread_curve_handle
+
+
+def srmodel_info():
+    callbond_model = {"name": "HullWhite",
+                            "vas_r0": 0.05,
+                            "vas_a": 0.1,
+                            "vas_b": 0.05,
+                            "vas_sigma": 0.01,
+                            "vas_lambda": 0.00,
+                            "bk_a": 0.1,
+                            "bk_sigma": 0.1,
+                            "hw_a": 0.1,
+                            "hw_sigma": 0.01,
+                            "gsr_step": None,
+                            "gsr_sigma": None,
+                            "gsr_reversion": None,
+                            "g2_a": 0.1,
+                            "g2_b": 0.1,
+                            "g2_sigma": 0.01,
+                            "g2_eta": 0.01,
+                            "g2_rho": -0.75,
+                        }
+    return callbond_model
\ No newline at end of file
